@@ -4,7 +4,7 @@ from itertools import chain
 class Extractor:
     @classmethod
     def filter_items(cls, collection, field, expected_value):
-        if type(expected_value) == tuple or type(expected_value) == list:
+        if isinstance(expected_value, (tuple, list)):
             gens = [
                 cls.filter_items(collection, field, expected_value[x])
                 for x in range(len(expected_value))
